@@ -186,20 +186,27 @@ class Definition:
 
 	def validate(self, results, field_fqn, field_name, definition, value, dependent_values):
 		try:
+			if not self.validator:
+				raise Config.exception_factory.create_internal_error(self.name, "Missing validator.")
 			if field_name is None:
 				field_name = self.name
-				#if self.data_type == DataType.Object:
-					#field_name = self.validator.model_validator.name
 			if field_fqn is None:
 				field_fqn = field_name
 				if self.data_type == DataType.Object:
 					field_fqn = self.validator.model_validator.name
 			normalized = Parameters.Index()
-			validator = self.validator
 			dependent_definition_name = self.dependency_resolver.get_dependent_definition(
 					field_fqn,
 					dependent_values
 				)
+			if value is None:
+				nullable = False
+				nullable = Index.is_nullable(self, field_name)
+				if nullable is True:
+					results[field_name] = None
+					return
+				else:
+					raise Config.exception_factory.create_input_error(field_name, 'Not nullable.')
 			if dependent_definition_name is not None:
 				Index.validate_input(
 						results,
@@ -210,7 +217,7 @@ class Definition:
 						dependent_values
 					)
 			else:
-				validator(normalized, field_fqn, field_name, self, value, dependent_values)
+				self.validator(normalized, field_fqn, field_name, self, value, dependent_values)
 			for rule in self.rules:
 				normalized[field_name] = rule.execute(field_fqn, normalized[field_name])
 			for transform in self.transforms:
@@ -427,31 +434,17 @@ class Index:
 		return results
 
 	def validate_input(validated, field_fqn, field_name, definition_or_name, value, dependent_values={}):
-		if isinstance(definition_or_name, Definition):
-			definition_name = definition_or_name.name
-		else:
-			definition_name = str(definition_or_name)
+		definition = Index.get(definition_or_name)
 		results = Parameters.Index.ensure(validated)
-		nullable = False
-		definition = Index.get(definition_name)
-		nullable = Index.is_nullable(definition_name)
-		if value is None:
-			if nullable is True or Config.definition_name_resolver.is_nullable(Index._idx, definition_name):
-				results[field_name] = None
-			else:
-				raise Config.exception_factory.create_input_error(field_name, 'Not nullable.')
-		else:
-			if not definition.validator:
-				raise Config.exception_factory.create_internal_error(definition_name, "Missing validator.")
-			definition.validate(results, field_fqn, field_name, definition, value, dependent_values)
+		definition.validate(results, field_fqn, field_name, definition, value, dependent_values)
 		return results
 
-	def is_nullable(name):
+	def is_nullable(definition_or_name, field_name):
 		nullable = False
-		if Config.definition_name_resolver.is_nullable(Index.as_dict(), name):
+		if Config.definition_name_resolver.is_nullable(Index.as_dict(), field_name):
 			nullable = True
 		else:
-			definition = Index.get(name)
+			definition = Index.get(definition_or_name)
 			nullable = definition.nullable
 		return nullable
 
